@@ -42,6 +42,8 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	iNeedDateRefresh = true;
 	iNeedDpkgRefresh = true;
 	iSkipRefreshListAndDates = false;
+	iLastListUpdate.setTime_t(0);
+	iLastDpkgUpdate.setTime_t(0);
 
 	iProcAptGetUpdate = new QProcess(this);
 	iProcAptGetSimulate = new QProcess(this);
@@ -845,7 +847,7 @@ void AAptInterface::uiUpdaterAptGetInstall()
 
 void AAptInterface::progressCheckTimerCallback()
 {
-	if( iAptGetCurrentDownloadFileName=="" )
+	if( iAptGetCurrentDownloadFileName.isEmpty() )
 		return;
 
 	qint64 prevsize = iAptGetCurrentFileDownloadSize;
@@ -902,7 +904,7 @@ QByteArray AAptInterface::readLogFile()
 		own.close();
 	}
 
-	if( log=="" )
+	if( log.isEmpty() )
 		log = "The log is empty";
 
 	return log;
@@ -970,7 +972,7 @@ void AAptInterface::readRepositoryInfo()
 		while(!names.atEnd() && c<iRepositories.count())
 		{
 			QString line = names.readLine().trimmed();
-			if( line.trimmed()!="" )
+			if( !line.trimmed().isEmpty() )
 			iRepositories.at(c)->setName( line.trimmed() );
 			c++;
 		}
@@ -1135,7 +1137,7 @@ void AAptInterface::startPkgListRead()
 	quint64 totaldatasize = 0;
 	quint64 currentreaddata = 0;
 	quint64 lastupdatedata = 0;
-	quint64 updateinterval = 1000000;
+	quint64 updateinterval = 2000000;
 	if( iNeedListRefresh && !iSkipRefreshListAndDates ) {
 		for( int i=0; i<files.count(); i++ )
 		{
@@ -1181,7 +1183,6 @@ void AAptInterface::startPkgListRead()
 
 				while (!db.atEnd() && !iTerminated) {
 					Package* newpkg = ReadNextPackage(db, currentreaddata);
-					//qDebug() << "read" << currentreaddata << "of" << totaldatasize;
 					if( iUiDimmer && currentreaddata >= lastupdatedata+updateinterval ) {
 						iUiDimmer->setProgress( currentreaddata*100/totaldatasize );
 						lastupdatedata = currentreaddata;
@@ -1233,6 +1234,7 @@ void AAptInterface::startPkgListRead()
 
 		iNeedListRefresh = false;
 		iNeedDateRefresh = true;
+		iLastListUpdate = QDateTime::currentDateTime();
 	}
 
 // read dpkg database (installed packages)
@@ -1264,7 +1266,7 @@ void AAptInterface::startPkgListRead()
 			}
 			pkgcount_dpkg++;
 			if( newpkg ) {
-				if( newpkg->isInstalled() ) {
+				if( newpkg->isInstalled() && !newpkg->name().isEmpty() ) {
 					iPackagesInstalled.insert(newpkg->name(), newpkg);
 				} else {
 					delete newpkg;
@@ -1286,6 +1288,7 @@ void AAptInterface::startPkgListRead()
 			return;
 		}
 		iNeedDpkgRefresh = false;
+		iLastDpkgUpdate = QDateTime::currentDateTime();
 	}
 
 	logToFile( QString("Finished reading package lists") );
@@ -1309,15 +1312,21 @@ Package* AAptInterface::ReadNextPackage(QFile& f, quint64& currentreaddata)
 	Package* pkg = new Package("", this);
 
 	bool pkgready = false;
+
+	// this is faster than directly reading to QByteArray...
+	char* data = new char[25000];
+	QByteArray line;
 	while( !pkgready && !f.atEnd() ) {
-		QByteArray line = f.readLine();
+		f.readLine(data,25000);
+		line = data;
 		currentreaddata += line.size();
 		if( processPackageDataLine(pkg,line) ) {
 			pkgready = true;
 		}
 	}
+	delete data;
 
-	if( pkg->name() != "" && pkg->isInstalled() ) {
+	if( !pkg->name().isEmpty() && pkg->isInstalled() ) {
 		QFileInfo f( KDpkgInfoDir + "/" + pkg->name() + ".list" );
 		if( f.exists() )
 			pkg->setDate( f.lastModified() );
@@ -1325,7 +1334,8 @@ Package* AAptInterface::ReadNextPackage(QFile& f, quint64& currentreaddata)
 
 	pkg->updateStatus();
 
-	if( pkg->name() == "" ) {
+	if( pkg->name().isEmpty() ) {
+		qDebug() << "null name package!";
 		delete pkg;
 		pkg = 0;
 	}
@@ -1334,74 +1344,13 @@ Package* AAptInterface::ReadNextPackage(QFile& f, quint64& currentreaddata)
 
 bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 {
-	if( !line.startsWith(' ') && !line.startsWith('\t') )
-		line = line.trimmed();
-	if( line.trimmed()=="" )
+	if( line.isEmpty() || line=="\n" )
+	{
 		return true;
-
-	if( line.startsWith("Package: ") )
-	{
-		pkg->setName( line.mid(9) );
-		iMultiLine=MultiLineNone;
-	}
-	else if( line.startsWith("Status: ") )
-	{
-		if( line.mid(8) == "install ok installed" )
-			pkg->setInstalled(true);
-		else
-			pkg->setInstalled(false);
-	}
-	else if( line.startsWith("Section: ") )
-	{
-		pkg->setSection( line.mid(9) );
-	}
-	else if( line.startsWith("Version: ") )
-	{
-		pkg->setVersion( line.mid(9) );
-	}
-	else if( line.startsWith("Filename: ") )
-	{
-		pkg->addFullFileName( line.mid(10) );
-	}
-	else if( line.startsWith("Size: ") )
-	{
-		pkg->setSize( line.mid(6).toInt() );
-	}
-	else if( line.startsWith("Installed-Size: ") )
-	{
-		pkg->setInstalledSize( line.mid(16).toInt() );
-	}
-	else if( line.startsWith("Maemo-Display-Name: ") )
-	{
-		pkg->setMaemoDisplayName( line.mid(20) );
-	}
-	else if( line.startsWith("Depends: ") )
-	{
-		pkg->appendDepends( line.mid(9) );
-	}
-	else if( line.startsWith("Conflicts: ") )
-	{
-		pkg->appendConflicts( line.mid(11) );
-	}
-	else if( line.startsWith("Pre-Depends: ") )
-	{
-		pkg->appendPreDepends( line.mid(13) );
-	}
-	else if( line.startsWith("Provides: ") )
-	{
-		pkg->appendProvides( line.mid(10) );
-	}
-	else if( line.startsWith("Replaces: ") )
-	{
-		pkg->appendReplaces( line.mid(10) );
-	}
-	else if( line.startsWith("Breaks: ") )
-	{
-		pkg->appendBreaks( line.mid(8) );
 	}
 
-	if( iMultiLine == MultiLineDesc ) {
-		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
+	else if( iMultiLine == MultiLineDesc ) {
+		if( (line.startsWith(' ') || line.startsWith('\t')) && !line.trimmed().isEmpty() ) {
 			if( line.trimmed()!="." )
 				pkg->appendDescLong( line.trimmed() + "\n" );
 			else
@@ -1411,21 +1360,90 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 		}
 	}
 	else if( iMultiLine == MultiLineIcon ) {
-		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
+		if( (line.startsWith(' ') || line.startsWith('\t')) && !line.trimmed().isEmpty() ) {
 			pkg->appendIconData( line.trimmed() );
 		} else {
 			iMultiLine = MultiLineNone;
 		}
 	}
 	else if( iMultiLine == MultiLineUpgradeDesc ) {
-		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
+		if( (line.startsWith(' ') || line.startsWith('\t')) && !line.trimmed().isEmpty() ) {
 			pkg->appendUpgradeDescription( line.trimmed() + "\n" );
 		} else {
 			iMultiLine = MultiLineNone;
 		}
 	}
 
-	if( line.startsWith("Description:") )
+	else if( line.startsWith("Package:") )
+	{
+		pkg->setName( line.mid(8).trimmed() );
+		iMultiLine=MultiLineNone;
+	}
+	else if( line.startsWith("Status:") )
+	{
+		if( line.mid(7).trimmed() == "install ok installed" )
+			pkg->setInstalled(true);
+		else
+			pkg->setInstalled(false);
+	}
+	else if( line.startsWith("Section:") )
+	{
+		pkg->setSection( line.mid(8).trimmed() );
+	}
+	else if( line.startsWith("Version:") )
+	{
+		pkg->setVersion( line.mid(8).trimmed() );
+	}
+	else if( line.startsWith("Filename:") )
+	{
+		pkg->addFullFileName( line.mid(9).trimmed() );
+	}
+	else if( line.startsWith("Size:") )
+	{
+		pkg->setSize( line.mid(5).trimmed().toInt() );
+	}
+	else if( line.startsWith("Installed-Size:") )
+	{
+		pkg->setInstalledSize( line.mid(15).trimmed().toInt() );
+	}
+	else if( line.startsWith("Maemo-Display-Name:") )
+	{
+		pkg->setMaemoDisplayName( line.mid(19).trimmed() );
+	}
+	else if( line.startsWith("Depends:") )
+	{
+		pkg->appendDepends( line.mid(8).trimmed() );
+	}
+	else if( line.startsWith("Conflicts:") )
+	{
+		pkg->appendConflicts( line.mid(10).trimmed() );
+	}
+	else if( line.startsWith("Pre-Depends:") )
+	{
+		pkg->appendPreDepends( line.mid(12).trimmed() );
+	}
+	else if( line.startsWith("Replaces:") )
+	{
+		pkg->appendReplaces( line.mid(9).trimmed() );
+	}
+	else if( line.startsWith("Recommends:") )
+	{
+		pkg->appendRecommends( line.mid(11).trimmed() );
+	}
+	else if( line.startsWith("Suggests:") )
+	{
+		pkg->appendSuggests( line.mid(9).trimmed() );
+	}
+	else if( line.startsWith("Provides:") )
+	{
+		pkg->appendProvides( line.mid(9).trimmed() );
+	}
+	else if( line.startsWith("Breaks:") )
+	{
+		pkg->appendBreaks( line.mid(7).trimmed() );
+	}
+
+	else if( line.startsWith("Description:") )
 	{
 		pkg->setDescShort( line.mid(12).trimmed() );
 		iMultiLine = MultiLineDesc;
@@ -1588,6 +1606,13 @@ void AAptInterface::startFetchDates()
 	}
 
 	QNetworkAccessManager* nam = new QNetworkAccessManager(this);
+
+	if( iSettings->qsettings()->value("use_proxies").toBool() && !iSettings->qsettings()->value("http_proxy").toString().isEmpty() )
+	{
+		 QNetworkProxy proxy = Settings::createProxyFromString( iSettings->qsettings()->value("http_proxy").toString() );
+		 nam->setProxy(proxy);
+	}
+
 	iCanCancel = true;
 
 	int count = 0;
@@ -1629,7 +1654,7 @@ void AAptInterface::startFetchDates()
 	{
 		fe.next();
 
-		if( updProgress >=10 ) {
+		if( updProgress >=20 ) {
 			iUiDimmer->setProgress( count*100/fetchable.count() );
 			updProgress=0;
 		}
@@ -1686,7 +1711,7 @@ void AAptInterface::startFetchDates()
 		}
 	}
 	while( iDateRequestsWaiting>0 ) {
-		if( updProgress >=10 ) {
+		if( updProgress >=20 ) {
 			iUiDimmer->setProgress( count*100/fetchable.count() );
 			updProgress=0;
 		}
