@@ -42,6 +42,7 @@ const QString KAptArchivePartialDir = "/var/cache/apt/archives/partial";
 const QString KDpkgStatusFile = "/var/lib/dpkg/status";
 const QString KDpkgInfoDir = "/var/lib/dpkg/info";
 
+const int KListExpireTime = 3600;
 
 class MainWindow;
 class FileReadThread;
@@ -96,6 +97,9 @@ public:
 
 	bool loadInstallFiles(QStringList files_);
 
+	QDateTime lastListUpdate() { return iLastListUpdate; }
+	QDateTime lastDpkgUpdate() { return iLastDpkgUpdate; }
+
 private:
 	void runNext();
 	void cleanAfterRunEach();
@@ -166,6 +170,8 @@ private:
 	bool iNeedDpkgRefresh;
 	bool iNeedDateRefresh;
 	bool iSkipRefreshListAndDates;
+	QDateTime iLastListUpdate;
+	QDateTime iLastDpkgUpdate;
 
 	QProcess* iProcAptGetUpdate;
 	QProcess* iProcAptGetSimulate;
