@@ -39,7 +39,7 @@ BlacklistSelect::BlacklistSelect(Package* pkg, QWidget *parent) :
 		ui->pushButton_Forever->setEnabled(false);
 	}
 
-	if( iPkg->isInstalled() )
+	if( iPkg->isInstalled() && !iPkg->isUpgradeable() )
 		ui->pushButton_This->setEnabled(false);
 }
 
