@@ -106,7 +106,7 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 		statusicon = iIconPkgRemove;
 	}
 
-	QString showVer = "";
+	QString showVer;
 	if( upgradeable && (statfilter==Package::PkgStatUpgradeable ||
 						(statfilter==Package::PkgStatUnknown && marked==Package::PkgOpInstallUpgrade) ||
 						(catfilter==PackageView::CatFilterAllMarked && marked==Package::PkgOpInstallUpgrade) ))
@@ -126,7 +126,7 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 			painter->drawText(r, Qt::AlignTop|Qt::AlignRight, showVer, &r);
 			ver_w = r.width();
 		} else if( blacklisted==BlacklistSelect::BlacklistThis ) {
-			if( upgradeable && upg_version!="" ) {
+			if( upgradeable && !upg_version.isEmpty() ) {
 				showVer = upg_version;
 			} else {
 				showVer = version;
@@ -268,6 +268,9 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 		listscroller->setDecelerationFactor(0.75); // default is 0.85
 		listscroller->setDragInertia(0.60);	// default is 0.85
 		listscroller->setMaximumVelocity(1800); // default is 3500
+
+		// not good because it alse sets horizontal overshoot:
+		//listscroller->setOvershootPolicy( QAbstractKineticScroller::OvershootAlwaysOn );
 	}
 }
 
@@ -293,7 +296,9 @@ void PackageView::resizeEvent(QResizeEvent* event)
 
 bool PackageView::doFilterCategory(Package* pkg)
 {
-	if( pkg->section()=="user/hidden" )
+	if( pkg->section()=="user/hidden" && iSelectedStatFilter!=Package::PkgStatInstalled && iSelectedStatFilter!=Package::PkgStatUnknown )
+		return false;
+	if( pkg->section()=="user/hidden" && !pkg->isInstalled() )
 		return false;
 
 	Package* upg_pkg = pkg->availablePackage();
@@ -485,7 +490,7 @@ void PackageView::addListItem(Package* pkg_, QString listname_)
 	if( pkg_ != 0 )
 	{
 		QString name = pkg_->name();
-		if( pkg_->maemoDisplayName()!="" )
+		if( !pkg_->maemoDisplayName().isEmpty() )
 			name = pkg_->maemoDisplayName();
 		p->setData(UserRoleName, name);
 	} else {
@@ -643,11 +648,24 @@ void PackageView::on_listWidget_itemClicked(QListWidgetItem* item)
 	if( upg_pkg )
 		bl_u = upg_pkg->isBlacklisted();
 
-	PackageSelector s(pkg, iAptInterface, this);
+	PackageSelector s(pkg, iAptInterface, iSettings, this);
 	s.exec();
+	Package::operation op = s.selectedOperation();
 
-	pkg->setMarkedForOperation( s.selectedOperation() );
-	item->setData(UserRoleMarked, (int)s.selectedOperation());
+	QStringList confl = pkg->checkConflicts_RichText();
+	if( confl.count() > 0 && op != Package::PkgOpNone ) {
+		ConfirmDialog d(true, this);
+		QString t = "Package " + pkg->name() + " conflicts with another installed or marked package. Mark anyway?";
+		t += "<font size=\"-1\"><br><br>Conflicts: ";
+		t += confl.join(", ");
+		t += "</font>";
+		d.setText("Conflicting packages", t);
+		if( !d.exec() )
+			op = Package::PkgOpNone;
+	}
+
+	pkg->setMarkedForOperation( op );
+	item->setData( UserRoleMarked, (int)op );
 	updateLabel();
 
 	if( pkg->isBlacklisted() != bl ) {
@@ -740,7 +758,7 @@ void PackageView::on_btn_StatusFilter_clicked()
 			iMainWindow->setNextOperation(MainWindow::OpOpenPkgView);
 			iMainWindow->busyDialog(true,"Operation in progress","Reading the rest of the package lists");
 
-			if( iAptInterface->needRepoRefresh() )
+			if( iAptInterface->needRepoRefresh() && !iSettings->qsettings()->value("no_catalogs_autoupdate",false).toBool() )
 				iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
 
 			iAptInterface->addQueuedOperation(AAptInterface::ModeReadPackages);
@@ -752,8 +770,6 @@ void PackageView::on_btn_StatusFilter_clicked()
 
 void PackageView::resetWindow()
 {
-	iMainWindow->resetIdlingTime();
-
 	iAptInterface->writeBlacklist();
 
 	ui->btn_StatusFilter->setEnabled(true);
@@ -811,7 +827,7 @@ void PackageView::on_lineEdit_textEdited(QString text)
 	if( !ui->searchBar->isVisible() )
 		return;
 
-	if( text=="" ) {
+	if( text.isEmpty() ) {
 		on_btn_searchClose_clicked();
 		return;
 	}
@@ -1023,7 +1039,7 @@ void PackageView::on_actionLoad_selections_triggered()
 				} else {
 					errors++;
 				}
-			} else if( line!="" ){
+			} else if( !line.isEmpty() ){
 				errors++;
 			}
 		}
