@@ -50,12 +50,12 @@ QStringList Repository::toListFileNames()
 		com << "";
 	for( int i=0; i<com.count(); i++ ) {
 		QString chopUrl = iUrl.mid( iUrl.indexOf("://")+3 );
-		if( com.at(i)!="" )
+		if( !com.at(i).isEmpty() )
 			disttext = "dists_";
 		else
 			disttext = "_";
 		QString str = chopUrl + iDir + disttext + iDist + "_" + com.at(i);
-		if( com.at(i)!="" )
+		if( !com.at(i).isEmpty() )
 			str += "_binary-armel_Packages";
 		else
 			str += "_Packages";
@@ -93,7 +93,7 @@ bool Repository::setFromString(QString repo)
 		iDir = parts.at(1).right( parts.at(1).length()-d-1 );
 	}
 
-	if( parts.at(2)!="" )
+	if( !parts.at(2).isEmpty() )
 		iDist = parts.at(2);
 	else
 		return false;
@@ -158,7 +158,7 @@ void Repository::set(QString name, QString url, QString dir, QString dist, QStri
 	if( !iUrl.endsWith('/') )
 		iUrl.append('/');
 	iDir = dir.trimmed();
-	if( !iDir.endsWith('/') && iDir!="" )
+	if( !iDir.endsWith('/') && !iDir.isEmpty() )
 		iDir.append('/');
 	iDist = dist.trimmed();
 	iComponents = components.trimmed();
